/****************************************************************************
** Meta object code from reading C++ file 'transportbase.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../transportbase.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transportbase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13MailTransport13TransportBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto MailTransport::TransportBase::qt_create_metaobjectdata<qt_meta_tag_ZN13MailTransport13TransportBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MailTransport::TransportBase",
        "idChanged",
        "",
        "nameChanged",
        "activitiesChanged",
        "activitiesEnabledChanged",
        "identifierChanged",
        "hostChanged",
        "portChanged",
        "userNameChanged",
        "precommandChanged",
        "optionsChanged",
        "requiresAuthenticationChanged",
        "storePasswordChanged",
        "encryptionChanged",
        "authenticationTypeChanged",
        "specifyHostnameChanged",
        "localHostnameChanged",
        "specifySenderOverwriteAddressChanged",
        "senderOverwriteAddressChanged",
        "useProxyChanged",
        "id",
        "isIdImmutable",
        "name",
        "isNameImmutable",
        "activities",
        "isActivitiesImmutable",
        "activitiesEnabled",
        "isActivitiesEnabledImmutable",
        "identifier",
        "isIdentifierImmutable",
        "host",
        "isHostImmutable",
        "port",
        "isPortImmutable",
        "userName",
        "isUserNameImmutable",
        "precommand",
        "isPrecommandImmutable",
        "options",
        "isOptionsImmutable",
        "requiresAuthentication",
        "isRequiresAuthenticationImmutable",
        "storePassword",
        "isStorePasswordImmutable",
        "encryption",
        "isEncryptionImmutable",
        "authenticationType",
        "isAuthenticationTypeImmutable",
        "specifyHostname",
        "isSpecifyHostnameImmutable",
        "localHostname",
        "isLocalHostnameImmutable",
        "specifySenderOverwriteAddress",
        "isSpecifySenderOverwriteAddressImmutable",
        "senderOverwriteAddress",
        "isSenderOverwriteAddressImmutable",
        "useProxy",
        "isUseProxyImmutable",
        "EnumEncryption",
        "None",
        "SSL",
        "TLS",
        "EnumAuthenticationType",
        "LOGIN",
        "PLAIN",
        "CRAM_MD5",
        "DIGEST_MD5",
        "GSSAPI",
        "NTLM",
        "APOP",
        "CLEAR",
        "ANONYMOUS",
        "XOAUTH2"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'idChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activitiesChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activitiesEnabledChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'identifierChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hostChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'portChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userNameChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'precommandChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'optionsChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requiresAuthenticationChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'storePasswordChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'encryptionChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authenticationTypeChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'specifyHostnameChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'localHostnameChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'specifySenderOverwriteAddressChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'senderOverwriteAddressChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useProxyChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isIdImmutable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isNameImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'activities'
        QtMocHelpers::PropertyData<QStringList>(25, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isActivitiesImmutable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'activitiesEnabled'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isActivitiesEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'identifier'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isIdentifierImmutable'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'host'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isHostImmutable'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'port'
        QtMocHelpers::PropertyData<uint>(33, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isPortImmutable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'userName'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isUserNameImmutable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'precommand'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isPrecommandImmutable'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'options'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isOptionsImmutable'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'requiresAuthentication'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isRequiresAuthenticationImmutable'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'storePassword'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isStorePasswordImmutable'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'encryption'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isEncryptionImmutable'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'authenticationType'
        QtMocHelpers::PropertyData<int>(47, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isAuthenticationTypeImmutable'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'specifyHostname'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isSpecifyHostnameImmutable'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'localHostname'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isLocalHostnameImmutable'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'specifySenderOverwriteAddress'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isSpecifySenderOverwriteAddressImmutable'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'senderOverwriteAddress'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isSenderOverwriteAddressImmutable'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useProxy'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isUseProxyImmutable'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'EnumEncryption'
        QtMocHelpers::EnumData<enum EnumEncryption>(59, 59, QMC::EnumFlags{}).add({
            {   60, EnumEncryption::None },
            {   61, EnumEncryption::SSL },
            {   62, EnumEncryption::TLS },
        }),
        // enum 'EnumAuthenticationType'
        QtMocHelpers::EnumData<enum EnumAuthenticationType>(63, 63, QMC::EnumFlags{}).add({
            {   64, EnumAuthenticationType::LOGIN },
            {   65, EnumAuthenticationType::PLAIN },
            {   66, EnumAuthenticationType::CRAM_MD5 },
            {   67, EnumAuthenticationType::DIGEST_MD5 },
            {   68, EnumAuthenticationType::GSSAPI },
            {   69, EnumAuthenticationType::NTLM },
            {   70, EnumAuthenticationType::APOP },
            {   71, EnumAuthenticationType::CLEAR },
            {   72, EnumAuthenticationType::ANONYMOUS },
            {   73, EnumAuthenticationType::XOAUTH2 },
        }),
    };
    return QtMocHelpers::metaObjectData<TransportBase, qt_meta_tag_ZN13MailTransport13TransportBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MailTransport::TransportBase::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MailTransport13TransportBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MailTransport13TransportBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13MailTransport13TransportBaseE_t>.metaTypes,
    nullptr
} };

void MailTransport::TransportBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransportBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->idChanged(); break;
        case 1: _t->nameChanged(); break;
        case 2: _t->activitiesChanged(); break;
        case 3: _t->activitiesEnabledChanged(); break;
        case 4: _t->identifierChanged(); break;
        case 5: _t->hostChanged(); break;
        case 6: _t->portChanged(); break;
        case 7: _t->userNameChanged(); break;
        case 8: _t->precommandChanged(); break;
        case 9: _t->optionsChanged(); break;
        case 10: _t->requiresAuthenticationChanged(); break;
        case 11: _t->storePasswordChanged(); break;
        case 12: _t->encryptionChanged(); break;
        case 13: _t->authenticationTypeChanged(); break;
        case 14: _t->specifyHostnameChanged(); break;
        case 15: _t->localHostnameChanged(); break;
        case 16: _t->specifySenderOverwriteAddressChanged(); break;
        case 17: _t->senderOverwriteAddressChanged(); break;
        case 18: _t->useProxyChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::idChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::activitiesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::activitiesEnabledChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::identifierChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::hostChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::portChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::userNameChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::precommandChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::optionsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::requiresAuthenticationChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::storePasswordChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::encryptionChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::authenticationTypeChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::specifyHostnameChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::localHostnameChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::specifySenderOverwriteAddressChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::senderOverwriteAddressChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportBase::*)()>(_a, &TransportBase::useProxyChanged, 18))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isIdImmutable(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isNameImmutable(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->activities(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isActivitiesImmutable(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->activitiesEnabled(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isActivitiesEnabledImmutable(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->identifier(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isIdentifierImmutable(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->host(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isHostImmutable(); break;
        case 12: *reinterpret_cast<uint*>(_v) = _t->port(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isPortImmutable(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->userName(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isUserNameImmutable(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->precommand(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->isPrecommandImmutable(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->options(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isOptionsImmutable(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->requiresAuthentication(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->isRequiresAuthenticationImmutable(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->storePassword(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->isStorePasswordImmutable(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->encryption(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isEncryptionImmutable(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->authenticationType(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->isAuthenticationTypeImmutable(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->specifyHostname(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->isSpecifyHostnameImmutable(); break;
        case 30: *reinterpret_cast<QString*>(_v) = _t->localHostname(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isLocalHostnameImmutable(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->specifySenderOverwriteAddress(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->isSpecifySenderOverwriteAddressImmutable(); break;
        case 34: *reinterpret_cast<QString*>(_v) = _t->senderOverwriteAddress(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->isSenderOverwriteAddressImmutable(); break;
        case 36: *reinterpret_cast<bool*>(_v) = _t->useProxy(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isUseProxyImmutable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setId(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setActivities(*reinterpret_cast<QStringList*>(_v)); break;
        case 6: _t->setActivitiesEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setIdentifier(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setHost(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setPort(*reinterpret_cast<uint*>(_v)); break;
        case 14: _t->setUserName(*reinterpret_cast<QString*>(_v)); break;
        case 16: _t->setPrecommand(*reinterpret_cast<QString*>(_v)); break;
        case 18: _t->setOptions(*reinterpret_cast<QString*>(_v)); break;
        case 20: _t->setRequiresAuthentication(*reinterpret_cast<bool*>(_v)); break;
        case 22: _t->setStorePassword(*reinterpret_cast<bool*>(_v)); break;
        case 24: _t->setEncryption(*reinterpret_cast<int*>(_v)); break;
        case 26: _t->setAuthenticationType(*reinterpret_cast<int*>(_v)); break;
        case 28: _t->setSpecifyHostname(*reinterpret_cast<bool*>(_v)); break;
        case 30: _t->setLocalHostname(*reinterpret_cast<QString*>(_v)); break;
        case 32: _t->setSpecifySenderOverwriteAddress(*reinterpret_cast<bool*>(_v)); break;
        case 34: _t->setSenderOverwriteAddress(*reinterpret_cast<QString*>(_v)); break;
        case 36: _t->setUseProxy(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MailTransport::TransportBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MailTransport::TransportBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MailTransport13TransportBaseE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int MailTransport::TransportBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    return _id;
}

// SIGNAL 0
void MailTransport::TransportBase::idChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MailTransport::TransportBase::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MailTransport::TransportBase::activitiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MailTransport::TransportBase::activitiesEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MailTransport::TransportBase::identifierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MailTransport::TransportBase::hostChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MailTransport::TransportBase::portChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MailTransport::TransportBase::userNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MailTransport::TransportBase::precommandChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void MailTransport::TransportBase::optionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void MailTransport::TransportBase::requiresAuthenticationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void MailTransport::TransportBase::storePasswordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void MailTransport::TransportBase::encryptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void MailTransport::TransportBase::authenticationTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void MailTransport::TransportBase::specifyHostnameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void MailTransport::TransportBase::localHostnameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void MailTransport::TransportBase::specifySenderOverwriteAddressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void MailTransport::TransportBase::senderOverwriteAddressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void MailTransport::TransportBase::useProxyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}
QT_WARNING_POP
