/********************************************************************************
** Form generated from reading UI file 'transportmanagementwidgetng.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TRANSPORTMANAGEMENTWIDGETNG_H
#define UI_TRANSPORTMANAGEMENTWIDGETNG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <widgets/transporttreeview.h>
#include "kseparator.h"

namespace MailTransport {

class Ui_TransportManagementWidgetNg
{
public:
    QGridLayout *gridLayout;
    QPushButton *editButton;
    MailTransport::TransportTreeView *transportTreeView;
    KSeparator *kseparator;
    QPushButton *removeButton;
    QPushButton *addButton;
    QPushButton *renameButton;
    QSpacerItem *spacerItem;
    QPushButton *defaultButton;
    QCheckBox *transportOnCurrentActivity;

    void setupUi(QWidget *MailTransport__TransportManagementWidgetNg)
    {
        if (MailTransport__TransportManagementWidgetNg->objectName().isEmpty())
            MailTransport__TransportManagementWidgetNg->setObjectName("MailTransport__TransportManagementWidgetNg");
        MailTransport__TransportManagementWidgetNg->resize(400, 300);
        gridLayout = new QGridLayout(MailTransport__TransportManagementWidgetNg);
        gridLayout->setObjectName("gridLayout");
        editButton = new QPushButton(MailTransport__TransportManagementWidgetNg);
        editButton->setObjectName("editButton");

        gridLayout->addWidget(editButton, 2, 1, 1, 1);

        transportTreeView = new MailTransport::TransportTreeView(MailTransport__TransportManagementWidgetNg);
        transportTreeView->setObjectName("transportTreeView");
        transportTreeView->setSelectionMode(QAbstractItemView::SelectionMode::ExtendedSelection);
        transportTreeView->setItemsExpandable(false);

        gridLayout->addWidget(transportTreeView, 1, 0, 7, 1);

        kseparator = new KSeparator(MailTransport__TransportManagementWidgetNg);
        kseparator->setObjectName("kseparator");

        gridLayout->addWidget(kseparator, 5, 1, 1, 1);

        removeButton = new QPushButton(MailTransport__TransportManagementWidgetNg);
        removeButton->setObjectName("removeButton");

        gridLayout->addWidget(removeButton, 4, 1, 1, 1);

        addButton = new QPushButton(MailTransport__TransportManagementWidgetNg);
        addButton->setObjectName("addButton");

        gridLayout->addWidget(addButton, 1, 1, 1, 1);

        renameButton = new QPushButton(MailTransport__TransportManagementWidgetNg);
        renameButton->setObjectName("renameButton");

        gridLayout->addWidget(renameButton, 3, 1, 1, 1);

        spacerItem = new QSpacerItem(20, 141, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 7, 1, 1, 1);

        defaultButton = new QPushButton(MailTransport__TransportManagementWidgetNg);
        defaultButton->setObjectName("defaultButton");

        gridLayout->addWidget(defaultButton, 6, 1, 1, 1);

        transportOnCurrentActivity = new QCheckBox(MailTransport__TransportManagementWidgetNg);
        transportOnCurrentActivity->setObjectName("transportOnCurrentActivity");

        gridLayout->addWidget(transportOnCurrentActivity, 0, 0, 1, 1);

        QWidget::setTabOrder(addButton, editButton);
        QWidget::setTabOrder(editButton, renameButton);
        QWidget::setTabOrder(renameButton, removeButton);
        QWidget::setTabOrder(removeButton, defaultButton);

        retranslateUi(MailTransport__TransportManagementWidgetNg);

        QMetaObject::connectSlotsByName(MailTransport__TransportManagementWidgetNg);
    } // setupUi

    void retranslateUi(QWidget *MailTransport__TransportManagementWidgetNg)
    {
        editButton->setText(tr2i18n("&Modify\342\200\246", nullptr));
        removeButton->setText(tr2i18n("Remo&ve", nullptr));
        addButton->setText(tr2i18n("A&dd\342\200\246", nullptr));
        renameButton->setText(tr2i18n("&Rename", nullptr));
        defaultButton->setText(tr2i18n("&Set as Default", nullptr));
        transportOnCurrentActivity->setText(tr2i18n("Show only transports on current activity", nullptr));
        (void)MailTransport__TransportManagementWidgetNg;
    } // retranslateUi

};

} // namespace MailTransport

namespace MailTransport {
namespace Ui {
    class TransportManagementWidgetNg: public Ui_TransportManagementWidgetNg {};
} // namespace Ui
} // namespace MailTransport

#endif // TRANSPORTMANAGEMENTWIDGETNG_H

