/********************************************************************************
** Form generated from reading UI file 'smtpsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SMTPSETTINGS_H
#define UI_SMTPSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "kpasswordlineedit.h"
#include "ktitlewidget.h"

QT_BEGIN_NAMESPACE

class Ui_SMTPSettings
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *smptTab;
    QFormLayout *formLayout_3;
    KTitleWidget *ktitlewidget;
    QLabel *hostLabel;
    KLineEdit *kcfg_host;
    QCheckBox *kcfg_requiresAuthentication;
    QLabel *usernameLabel;
    KLineEdit *kcfg_userName;
    QLabel *passwordLabel;
    KPasswordLineEdit *password;
    QCheckBox *kcfg_storePassword;
    QSpacerItem *verticalSpacer;
    QWidget *advancedTab;
    QFormLayout *formLayout;
    KTitleWidget *ktitlewidget_2;
    QLabel *noAuthPossible;
    QStackedWidget *checkCapabilitiesStack;
    QWidget *page;
    QVBoxLayout *verticalLayout_3;
    QPushButton *checkCapabilities;
    QWidget *page_2;
    QVBoxLayout *verticalLayout_4;
    QProgressBar *checkCapabilitiesProgress;
    QFormLayout *formLayout_2;
    QLabel *label;
    QHBoxLayout *encryptHLayout;
    QRadioButton *encryptionNone;
    QRadioButton *encryptionSsl;
    QRadioButton *encryptionTls;
    QLabel *portLabel;
    QSpinBox *kcfg_port;
    QLabel *authLabel;
    QComboBox *authCombo;
    QCheckBox *kcfg_useProxy;
    KTitleWidget *ktitlewidget_3;
    QLabel *hostnameLabel;
    KLineEdit *kcfg_localHostname;
    QLabel *label_2;
    KLineEdit *kcfg_senderOverwriteAddress;
    QLabel *precommandLabel;
    KLineEdit *kcfg_precommand;
    QSpacerItem *verticalSpacer_2;
    QCheckBox *kcfg_specifyHostname;
    QCheckBox *kcfg_specifySenderOverwriteAddress;

    void setupUi(QWidget *SMTPSettings)
    {
        if (SMTPSettings->objectName().isEmpty())
            SMTPSettings->setObjectName("SMTPSettings");
        SMTPSettings->resize(411, 492);
        verticalLayout = new QVBoxLayout(SMTPSettings);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(SMTPSettings);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setDocumentMode(true);
        smptTab = new QWidget();
        smptTab->setObjectName("smptTab");
        formLayout_3 = new QFormLayout(smptTab);
        formLayout_3->setObjectName("formLayout_3");
        ktitlewidget = new KTitleWidget(smptTab);
        ktitlewidget->setObjectName("ktitlewidget");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::SpanningRole, ktitlewidget);

        hostLabel = new QLabel(smptTab);
        hostLabel->setObjectName("hostLabel");
        hostLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, hostLabel);

        kcfg_host = new KLineEdit(smptTab);
        kcfg_host->setObjectName("kcfg_host");
        kcfg_host->setProperty("trapEnterKeyEvent", QVariant(true));

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_host);

        kcfg_requiresAuthentication = new QCheckBox(smptTab);
        kcfg_requiresAuthentication->setObjectName("kcfg_requiresAuthentication");

        formLayout_3->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_requiresAuthentication);

        usernameLabel = new QLabel(smptTab);
        usernameLabel->setObjectName("usernameLabel");
        usernameLabel->setEnabled(false);
        usernameLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_3->setWidget(5, QFormLayout::ItemRole::LabelRole, usernameLabel);

        kcfg_userName = new KLineEdit(smptTab);
        kcfg_userName->setObjectName("kcfg_userName");
        kcfg_userName->setEnabled(false);
        kcfg_userName->setProperty("trapEnterKeyEvent", QVariant(true));

        formLayout_3->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_userName);

        passwordLabel = new QLabel(smptTab);
        passwordLabel->setObjectName("passwordLabel");
        passwordLabel->setEnabled(false);
        passwordLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_3->setWidget(7, QFormLayout::ItemRole::LabelRole, passwordLabel);

        password = new KPasswordLineEdit(smptTab);
        password->setObjectName("password");
        password->setEnabled(false);

        formLayout_3->setWidget(7, QFormLayout::ItemRole::FieldRole, password);

        kcfg_storePassword = new QCheckBox(smptTab);
        kcfg_storePassword->setObjectName("kcfg_storePassword");
        kcfg_storePassword->setEnabled(false);

        formLayout_3->setWidget(9, QFormLayout::ItemRole::FieldRole, kcfg_storePassword);

        verticalSpacer = new QSpacerItem(20, 208, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout_3->setItem(11, QFormLayout::ItemRole::FieldRole, verticalSpacer);

        tabWidget->addTab(smptTab, QString());
        advancedTab = new QWidget();
        advancedTab->setObjectName("advancedTab");
        formLayout = new QFormLayout(advancedTab);
        formLayout->setObjectName("formLayout");
        ktitlewidget_2 = new KTitleWidget(advancedTab);
        ktitlewidget_2->setObjectName("ktitlewidget_2");

        formLayout->setWidget(0, QFormLayout::ItemRole::SpanningRole, ktitlewidget_2);

        noAuthPossible = new QLabel(advancedTab);
        noAuthPossible->setObjectName("noAuthPossible");
        noAuthPossible->setVisible(false);
        noAuthPossible->setFrameShape(QFrame::Box);
        noAuthPossible->setFrameShadow(QFrame::Plain);
        noAuthPossible->setLineWidth(0);
        noAuthPossible->setAlignment(Qt::AlignCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, noAuthPossible);

        checkCapabilitiesStack = new QStackedWidget(advancedTab);
        checkCapabilitiesStack->setObjectName("checkCapabilitiesStack");
        page = new QWidget();
        page->setObjectName("page");
        verticalLayout_3 = new QVBoxLayout(page);
        verticalLayout_3->setObjectName("verticalLayout_3");
        checkCapabilities = new QPushButton(page);
        checkCapabilities->setObjectName("checkCapabilities");

        verticalLayout_3->addWidget(checkCapabilities);

        checkCapabilitiesStack->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        verticalLayout_4 = new QVBoxLayout(page_2);
        verticalLayout_4->setObjectName("verticalLayout_4");
        checkCapabilitiesProgress = new QProgressBar(page_2);
        checkCapabilitiesProgress->setObjectName("checkCapabilitiesProgress");
        checkCapabilitiesProgress->setValue(0);

        verticalLayout_4->addWidget(checkCapabilitiesProgress);

        checkCapabilitiesStack->addWidget(page_2);

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, checkCapabilitiesStack);

        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label = new QLabel(advancedTab);
        label->setObjectName("label");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        encryptHLayout = new QHBoxLayout();
        encryptHLayout->setObjectName("encryptHLayout");
        encryptionNone = new QRadioButton(advancedTab);
        encryptionNone->setObjectName("encryptionNone");

        encryptHLayout->addWidget(encryptionNone);

        encryptionSsl = new QRadioButton(advancedTab);
        encryptionSsl->setObjectName("encryptionSsl");

        encryptHLayout->addWidget(encryptionSsl);

        encryptionTls = new QRadioButton(advancedTab);
        encryptionTls->setObjectName("encryptionTls");

        encryptHLayout->addWidget(encryptionTls);


        formLayout_2->setLayout(0, QFormLayout::ItemRole::FieldRole, encryptHLayout);

        portLabel = new QLabel(advancedTab);
        portLabel->setObjectName("portLabel");
        portLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, portLabel);

        kcfg_port = new QSpinBox(advancedTab);
        kcfg_port->setObjectName("kcfg_port");
        kcfg_port->setMinimum(1);
        kcfg_port->setMaximum(65535);
        kcfg_port->setValue(25);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_port);

        authLabel = new QLabel(advancedTab);
        authLabel->setObjectName("authLabel");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, authLabel);

        authCombo = new QComboBox(advancedTab);
        authCombo->setObjectName("authCombo");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, authCombo);

        kcfg_useProxy = new QCheckBox(advancedTab);
        kcfg_useProxy->setObjectName("kcfg_useProxy");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_useProxy);


        formLayout->setLayout(3, QFormLayout::ItemRole::SpanningRole, formLayout_2);

        ktitlewidget_3 = new KTitleWidget(advancedTab);
        ktitlewidget_3->setObjectName("ktitlewidget_3");

        formLayout->setWidget(4, QFormLayout::ItemRole::SpanningRole, ktitlewidget_3);

        hostnameLabel = new QLabel(advancedTab);
        hostnameLabel->setObjectName("hostnameLabel");
        hostnameLabel->setEnabled(false);
        hostnameLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, hostnameLabel);

        kcfg_localHostname = new KLineEdit(advancedTab);
        kcfg_localHostname->setObjectName("kcfg_localHostname");
        kcfg_localHostname->setEnabled(false);
        kcfg_localHostname->setProperty("trapEnterKeyEvent", QVariant(true));

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, kcfg_localHostname);

        label_2 = new QLabel(advancedTab);
        label_2->setObjectName("label_2");
        label_2->setEnabled(false);

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_senderOverwriteAddress = new KLineEdit(advancedTab);
        kcfg_senderOverwriteAddress->setObjectName("kcfg_senderOverwriteAddress");
        kcfg_senderOverwriteAddress->setEnabled(false);
        kcfg_senderOverwriteAddress->setProperty("trapEnterKeyEvent", QVariant(true));

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, kcfg_senderOverwriteAddress);

        precommandLabel = new QLabel(advancedTab);
        precommandLabel->setObjectName("precommandLabel");
        precommandLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(9, QFormLayout::ItemRole::LabelRole, precommandLabel);

        kcfg_precommand = new KLineEdit(advancedTab);
        kcfg_precommand->setObjectName("kcfg_precommand");
        kcfg_precommand->setProperty("trapEnterKeyEvent", QVariant(true));

        formLayout->setWidget(9, QFormLayout::ItemRole::FieldRole, kcfg_precommand);

        verticalSpacer_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(10, QFormLayout::ItemRole::LabelRole, verticalSpacer_2);

        kcfg_specifyHostname = new QCheckBox(advancedTab);
        kcfg_specifyHostname->setObjectName("kcfg_specifyHostname");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_specifyHostname);

        kcfg_specifySenderOverwriteAddress = new QCheckBox(advancedTab);
        kcfg_specifySenderOverwriteAddress->setObjectName("kcfg_specifySenderOverwriteAddress");

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, kcfg_specifySenderOverwriteAddress);

        tabWidget->addTab(advancedTab, QString());

        verticalLayout->addWidget(tabWidget);

#if QT_CONFIG(shortcut)
        hostLabel->setBuddy(kcfg_host);
        usernameLabel->setBuddy(kcfg_userName);
        passwordLabel->setBuddy(password);
        portLabel->setBuddy(kcfg_port);
        hostnameLabel->setBuddy(kcfg_localHostname);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(checkCapabilities, encryptionNone);
        QWidget::setTabOrder(encryptionNone, encryptionSsl);
        QWidget::setTabOrder(encryptionSsl, encryptionTls);
        QWidget::setTabOrder(encryptionTls, authCombo);

        retranslateUi(SMTPSettings);
        QObject::connect(kcfg_specifyHostname, &QCheckBox::toggled, hostnameLabel, &QLabel::setEnabled);
        QObject::connect(kcfg_specifyHostname, SIGNAL(toggled(bool)), kcfg_localHostname, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_requiresAuthentication, SIGNAL(toggled(bool)), kcfg_userName, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_requiresAuthentication, &QCheckBox::toggled, usernameLabel, &QLabel::setEnabled);
        QObject::connect(kcfg_requiresAuthentication, &QCheckBox::toggled, passwordLabel, &QLabel::setEnabled);
        QObject::connect(kcfg_requiresAuthentication, SIGNAL(toggled(bool)), password, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_requiresAuthentication, &QCheckBox::toggled, kcfg_storePassword, &QCheckBox::setEnabled);
        QObject::connect(kcfg_specifySenderOverwriteAddress, &QCheckBox::toggled, label_2, &QLabel::setEnabled);
        QObject::connect(kcfg_specifySenderOverwriteAddress, SIGNAL(toggled(bool)), kcfg_senderOverwriteAddress, SLOT(setEnabled(bool)));

        tabWidget->setCurrentIndex(0);
        checkCapabilitiesStack->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(SMTPSettings);
    } // setupUi

    void retranslateUi(QWidget *SMTPSettings)
    {
        ktitlewidget->setText(tr2i18n("Account Information", nullptr));
        hostLabel->setText(tr2i18n("Outgoing &mail server:", nullptr));
        kcfg_requiresAuthentication->setText(tr2i18n("Server &requires authentication", nullptr));
        usernameLabel->setText(tr2i18n("&Login:", nullptr));
        passwordLabel->setText(tr2i18n("P&assword:", nullptr));
        kcfg_storePassword->setText(tr2i18n("&Store SMTP password", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(smptTab), tr2i18n("General", "general smtp settings"));
        ktitlewidget_2->setText(tr2i18n("Connection Settings", nullptr));
        noAuthPossible->setText(tr2i18n("This server does not support authentication", nullptr));
        checkCapabilities->setText(tr2i18n("Auto Detect", nullptr));
        label->setText(tr2i18n("Encryption:", nullptr));
        encryptionNone->setText(tr2i18n("&None", nullptr));
        encryptionSsl->setText(tr2i18n("&SSL/TLS", nullptr));
        encryptionTls->setText(tr2i18n("START&TLS", nullptr));
        portLabel->setText(tr2i18n("&Port:", nullptr));
        authLabel->setText(tr2i18n("Authentication:", nullptr));
        kcfg_useProxy->setText(tr2i18n("Connect using the system proxy settings", nullptr));
        ktitlewidget_3->setText(tr2i18n("SMTP Settings", nullptr));
        hostnameLabel->setText(tr2i18n("Hostna&me:", nullptr));
        label_2->setText(tr2i18n("Sender Address:", nullptr));
        precommandLabel->setText(tr2i18n("Precommand:", nullptr));
        kcfg_specifyHostname->setText(tr2i18n("Sen&d custom hostname to server", nullptr));
        kcfg_specifySenderOverwriteAddress->setText(tr2i18n("Use custom sender address", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(advancedTab), tr2i18n("Advanced", "advanced smtp settings"));
        (void)SMTPSettings;
    } // retranslateUi

};

namespace Ui {
    class SMTPSettings: public Ui_SMTPSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SMTPSETTINGS_H

