/********************************************************************************
** Form generated from reading UI file 'addtransportdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDTRANSPORTDIALOG_H
#define UI_ADDTRANSPORTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_AddTransportDialog
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *name;
    QCheckBox *setDefault;
    QLabel *descLabel;
    QTreeWidget *typeListView;

    void setupUi(QWidget *AddTransportDialog)
    {
        if (AddTransportDialog->objectName().isEmpty())
            AddTransportDialog->setObjectName("AddTransportDialog");
        AddTransportDialog->resize(482, 353);
        AddTransportDialog->setMinimumSize(QSize(0, 0));
        gridLayout = new QGridLayout(AddTransportDialog);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(AddTransportDialog);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        name = new QLineEdit(AddTransportDialog);
        name->setObjectName("name");

        gridLayout->addWidget(name, 0, 1, 1, 1);

        setDefault = new QCheckBox(AddTransportDialog);
        setDefault->setObjectName("setDefault");

        gridLayout->addWidget(setDefault, 1, 1, 1, 1);

        descLabel = new QLabel(AddTransportDialog);
        descLabel->setObjectName("descLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(descLabel->sizePolicy().hasHeightForWidth());
        descLabel->setSizePolicy(sizePolicy);
        descLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        descLabel->setWordWrap(true);

        gridLayout->addWidget(descLabel, 2, 0, 1, 2);

        typeListView = new QTreeWidget(AddTransportDialog);
        typeListView->setObjectName("typeListView");
        typeListView->setAlternatingRowColors(true);
        typeListView->setRootIsDecorated(false);

        gridLayout->addWidget(typeListView, 3, 0, 1, 2);


        retranslateUi(AddTransportDialog);

        QMetaObject::connectSlotsByName(AddTransportDialog);
    } // setupUi

    void retranslateUi(QWidget *AddTransportDialog)
    {
        AddTransportDialog->setWindowTitle(tr2i18n("Step One: Select Transport Type", nullptr));
        label->setText(tr2i18n("Name:", "The name of a mail transport"));
        setDefault->setText(tr2i18n("Make this the default outgoing account", nullptr));
        descLabel->setText(tr2i18n("Select an account type from the list below:", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = typeListView->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Description", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Type", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AddTransportDialog: public Ui_AddTransportDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ADDTRANSPORTDIALOG_H

